import sys
import pdb

def err_hook():
  sys_legacy_hook = sys.excepthook
  def new_hook(type, value, traceback):
    sys_legacy_hook(type, value, traceback)
    pdb.post_mortem(traceback)
  sys.excepthook = new_hook


from setuptools import setup, find_packages

setup(
  name = 'shy',
  version = '0.1.1',
  description = 'very shy library',
  author = 'kevin970401',
  author_email = 'kevin970401@gmail.com',
  url = 'http://github.com/kevin970401/shy',
  install_requires = [],
  packages = find_packages(exclude = ['docs', 'test*']),
  keywords = ['shy'],
  python_requires = '>=3',
  zip_safe = False,
  license = 'MIT'
)